# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKDistanceMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkFastChamferDistanceImageFilterPython
else:
    import _itkFastChamferDistanceImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.pyBasePython
import itk.itkOffsetPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.ITKNarrowBandBasePython

def itkFastChamferDistanceImageFilterIF2IF2_New():
    return itkFastChamferDistanceImageFilterIF2IF2.New()

class itkFastChamferDistanceImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkFastChamferDistanceImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastChamferDistanceImageFilterIF2IF2_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastChamferDistanceImageFilterIF2IF2_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_Clone(self)

    def SetWeights(self, _arg):
        r"""
        SetWeights(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayF2

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_SetWeights(self, _arg)

    def GetWeights(self):
        r"""GetWeights(self) -> itkFixedArrayF2"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_GetWeights(self)

    def SetMaximumDistance(self, _arg):
        r"""
        SetMaximumDistance(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_SetMaximumDistance(self, _arg)

    def GetMaximumDistance(self):
        r"""GetMaximumDistance(self) -> float"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_GetMaximumDistance(self)

    def SetRegionToProcess(self, r):
        r"""
        SetRegionToProcess(self, r)

        Parameters
        ----------
        r: itkImageRegion2 const &

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_SetRegionToProcess(self, r)

    def GetRegionToProcess(self):
        r"""GetRegionToProcess(self) -> itkImageRegion2"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_GetRegionToProcess(self)

    def SetNarrowBand(self, ptr):
        r"""
        SetNarrowBand(self, ptr)

        Parameters
        ----------
        ptr: itkNarrowBandBNI2F *

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_SetNarrowBand(self, ptr)

    def GetNarrowBand(self):
        r"""GetNarrowBand(self) -> itkNarrowBandBNI2F_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_GetNarrowBand(self)
    SameDimensionCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_SameDimensionCheck
    
    SameTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_SameTypeCheck
    
    FloatConvertibleToPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_FloatConvertibleToPixelTypeCheck
    
    PixelTypeConvertibleToFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_PixelTypeConvertibleToFloatCheck
    
    PixelTypeGreaterThanFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_PixelTypeGreaterThanFloatCheck
    
    PixelTypeLessThanFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_PixelTypeLessThanFloatCheck
    
    PixelTypeFloatAdditiveOperatorsCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_PixelTypeFloatAdditiveOperatorsCheck
    
    FloatGreaterThanPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_FloatGreaterThanPixelTypeCheck
    
    FloatLessThanPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_FloatLessThanPixelTypeCheck
    
    __swig_destroy__ = _itkFastChamferDistanceImageFilterPython.delete_itkFastChamferDistanceImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastChamferDistanceImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastChamferDistanceImageFilterIF2IF2

        Create a new object of the class itkFastChamferDistanceImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastChamferDistanceImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastChamferDistanceImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastChamferDistanceImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastChamferDistanceImageFilterIF2IF2 in _itkFastChamferDistanceImageFilterPython:
_itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF2IF2_swigregister(itkFastChamferDistanceImageFilterIF2IF2)

def itkFastChamferDistanceImageFilterIF3IF3_New():
    return itkFastChamferDistanceImageFilterIF3IF3.New()

class itkFastChamferDistanceImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkFastChamferDistanceImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastChamferDistanceImageFilterIF3IF3_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastChamferDistanceImageFilterIF3IF3_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_Clone(self)

    def SetWeights(self, _arg):
        r"""
        SetWeights(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayF3

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_SetWeights(self, _arg)

    def GetWeights(self):
        r"""GetWeights(self) -> itkFixedArrayF3"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_GetWeights(self)

    def SetMaximumDistance(self, _arg):
        r"""
        SetMaximumDistance(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_SetMaximumDistance(self, _arg)

    def GetMaximumDistance(self):
        r"""GetMaximumDistance(self) -> float"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_GetMaximumDistance(self)

    def SetRegionToProcess(self, r):
        r"""
        SetRegionToProcess(self, r)

        Parameters
        ----------
        r: itkImageRegion3 const &

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_SetRegionToProcess(self, r)

    def GetRegionToProcess(self):
        r"""GetRegionToProcess(self) -> itkImageRegion3"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_GetRegionToProcess(self)

    def SetNarrowBand(self, ptr):
        r"""
        SetNarrowBand(self, ptr)

        Parameters
        ----------
        ptr: itkNarrowBandBNI3F *

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_SetNarrowBand(self, ptr)

    def GetNarrowBand(self):
        r"""GetNarrowBand(self) -> itkNarrowBandBNI3F_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_GetNarrowBand(self)
    SameDimensionCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_SameDimensionCheck
    
    SameTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_SameTypeCheck
    
    FloatConvertibleToPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_FloatConvertibleToPixelTypeCheck
    
    PixelTypeConvertibleToFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_PixelTypeConvertibleToFloatCheck
    
    PixelTypeGreaterThanFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_PixelTypeGreaterThanFloatCheck
    
    PixelTypeLessThanFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_PixelTypeLessThanFloatCheck
    
    PixelTypeFloatAdditiveOperatorsCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_PixelTypeFloatAdditiveOperatorsCheck
    
    FloatGreaterThanPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_FloatGreaterThanPixelTypeCheck
    
    FloatLessThanPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_FloatLessThanPixelTypeCheck
    
    __swig_destroy__ = _itkFastChamferDistanceImageFilterPython.delete_itkFastChamferDistanceImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastChamferDistanceImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastChamferDistanceImageFilterIF3IF3

        Create a new object of the class itkFastChamferDistanceImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastChamferDistanceImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastChamferDistanceImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastChamferDistanceImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastChamferDistanceImageFilterIF3IF3 in _itkFastChamferDistanceImageFilterPython:
_itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterIF3IF3_swigregister(itkFastChamferDistanceImageFilterIF3IF3)

def itkFastChamferDistanceImageFilterISS2ISS2_New():
    return itkFastChamferDistanceImageFilterISS2ISS2.New()

class itkFastChamferDistanceImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkFastChamferDistanceImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastChamferDistanceImageFilterISS2ISS2_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastChamferDistanceImageFilterISS2ISS2_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_Clone(self)

    def SetWeights(self, _arg):
        r"""
        SetWeights(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayF2

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_SetWeights(self, _arg)

    def GetWeights(self):
        r"""GetWeights(self) -> itkFixedArrayF2"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_GetWeights(self)

    def SetMaximumDistance(self, _arg):
        r"""
        SetMaximumDistance(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_SetMaximumDistance(self, _arg)

    def GetMaximumDistance(self):
        r"""GetMaximumDistance(self) -> float"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_GetMaximumDistance(self)

    def SetRegionToProcess(self, r):
        r"""
        SetRegionToProcess(self, r)

        Parameters
        ----------
        r: itkImageRegion2 const &

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_SetRegionToProcess(self, r)

    def GetRegionToProcess(self):
        r"""GetRegionToProcess(self) -> itkImageRegion2"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_GetRegionToProcess(self)

    def SetNarrowBand(self, ptr):
        r"""
        SetNarrowBand(self, ptr)

        Parameters
        ----------
        ptr: itkNarrowBandBNI2SS *

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_SetNarrowBand(self, ptr)

    def GetNarrowBand(self):
        r"""GetNarrowBand(self) -> itkNarrowBandBNI2SS_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_GetNarrowBand(self)
    SameDimensionCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_SameDimensionCheck
    
    SameTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_SameTypeCheck
    
    FloatConvertibleToPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_FloatConvertibleToPixelTypeCheck
    
    PixelTypeConvertibleToFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_PixelTypeConvertibleToFloatCheck
    
    PixelTypeGreaterThanFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_PixelTypeGreaterThanFloatCheck
    
    PixelTypeLessThanFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_PixelTypeLessThanFloatCheck
    
    PixelTypeFloatAdditiveOperatorsCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_PixelTypeFloatAdditiveOperatorsCheck
    
    FloatGreaterThanPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_FloatGreaterThanPixelTypeCheck
    
    FloatLessThanPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_FloatLessThanPixelTypeCheck
    
    __swig_destroy__ = _itkFastChamferDistanceImageFilterPython.delete_itkFastChamferDistanceImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastChamferDistanceImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastChamferDistanceImageFilterISS2ISS2

        Create a new object of the class itkFastChamferDistanceImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastChamferDistanceImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastChamferDistanceImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastChamferDistanceImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastChamferDistanceImageFilterISS2ISS2 in _itkFastChamferDistanceImageFilterPython:
_itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS2ISS2_swigregister(itkFastChamferDistanceImageFilterISS2ISS2)

def itkFastChamferDistanceImageFilterISS3ISS3_New():
    return itkFastChamferDistanceImageFilterISS3ISS3.New()

class itkFastChamferDistanceImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkFastChamferDistanceImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastChamferDistanceImageFilterISS3ISS3_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastChamferDistanceImageFilterISS3ISS3_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_Clone(self)

    def SetWeights(self, _arg):
        r"""
        SetWeights(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayF3

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_SetWeights(self, _arg)

    def GetWeights(self):
        r"""GetWeights(self) -> itkFixedArrayF3"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_GetWeights(self)

    def SetMaximumDistance(self, _arg):
        r"""
        SetMaximumDistance(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_SetMaximumDistance(self, _arg)

    def GetMaximumDistance(self):
        r"""GetMaximumDistance(self) -> float"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_GetMaximumDistance(self)

    def SetRegionToProcess(self, r):
        r"""
        SetRegionToProcess(self, r)

        Parameters
        ----------
        r: itkImageRegion3 const &

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_SetRegionToProcess(self, r)

    def GetRegionToProcess(self):
        r"""GetRegionToProcess(self) -> itkImageRegion3"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_GetRegionToProcess(self)

    def SetNarrowBand(self, ptr):
        r"""
        SetNarrowBand(self, ptr)

        Parameters
        ----------
        ptr: itkNarrowBandBNI3SS *

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_SetNarrowBand(self, ptr)

    def GetNarrowBand(self):
        r"""GetNarrowBand(self) -> itkNarrowBandBNI3SS_Pointer"""
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_GetNarrowBand(self)
    SameDimensionCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_SameDimensionCheck
    
    SameTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_SameTypeCheck
    
    FloatConvertibleToPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_FloatConvertibleToPixelTypeCheck
    
    PixelTypeConvertibleToFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_PixelTypeConvertibleToFloatCheck
    
    PixelTypeGreaterThanFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_PixelTypeGreaterThanFloatCheck
    
    PixelTypeLessThanFloatCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_PixelTypeLessThanFloatCheck
    
    PixelTypeFloatAdditiveOperatorsCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_PixelTypeFloatAdditiveOperatorsCheck
    
    FloatGreaterThanPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_FloatGreaterThanPixelTypeCheck
    
    FloatLessThanPixelTypeCheck = _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_FloatLessThanPixelTypeCheck
    
    __swig_destroy__ = _itkFastChamferDistanceImageFilterPython.delete_itkFastChamferDistanceImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastChamferDistanceImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastChamferDistanceImageFilterISS3ISS3

        Create a new object of the class itkFastChamferDistanceImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastChamferDistanceImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastChamferDistanceImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastChamferDistanceImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastChamferDistanceImageFilterISS3ISS3 in _itkFastChamferDistanceImageFilterPython:
_itkFastChamferDistanceImageFilterPython.itkFastChamferDistanceImageFilterISS3ISS3_swigregister(itkFastChamferDistanceImageFilterISS3ISS3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def fast_chamfer_distance_image_filter(*args: itkt.ImageLike,  weights: Sequence[float]=..., maximum_distance: float=..., region_to_process: itkt.ImageRegion=..., narrow_band=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for FastChamferDistanceImageFilter"""
    import itk

    kwarg_typehints = { 'weights':weights,'maximum_distance':maximum_distance,'region_to_process':region_to_process,'narrow_band':narrow_band }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.FastChamferDistanceImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def fast_chamfer_distance_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKDistanceMap.FastChamferDistanceImageFilter
    fast_chamfer_distance_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    fast_chamfer_distance_image_filter.__doc__ = filter_object.__doc__



